Anomaly scores — skchange

Skip to main content
`Ctrl`+`K`

# Anomaly scores

## Savings

`BaseSaving`() | Base class template for savings.
`Saving`([baseline_cost]) | Saving based on a cost class.
`L2Saving`() | L2 saving for a zero-valued baseline mean.

## Local anomaly scores

`BaseLocalAnomalyScore`() | Base class template for local anomaly scores.
`LocalAnomalyScore`([cost]) | Local anomaly scores based on costs.

## Utility functions

`to_saving`(scorer) | Convert compatible scorers to a saving.
`to_local_anomaly_score`(scorer) | Convert compatible scorers to a saving.